@@ -41,10 +41,10 @@
 #include <limits.h>
 #include <ctype.h>
 
-#if defined(CPU_COUNT) && (CPU_COUNT+0) < 2
+#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
 #undef CPU_COUNT
 #endif
-#if !defined(CPU_COUNT)
+#if ! defined(CPU_COUNT)
 #define CPU_COUNT 2
 #endif
 
@@ -73,46 +73,50 @@
 /**
  * Page returned for file-not-found.
  */
-#define FILE_NOT_FOUND_PAGE "<html><head><title>File not found</title></head><body>File not found</body></html>"
+#define FILE_NOT_FOUND_PAGE \
+  "<html><head><title>File not found</title></head><body>File not found</body></html>"
 
 
 /**
  * Page returned for internal errors.
  */
-#define INTERNAL_ERROR_PAGE "<html><head><title>Internal error</title></head><body>Internal error</body></html>"
+#define INTERNAL_ERROR_PAGE \
+  "<html><head><title>Internal error</title></head><body>Internal error</body></html>"
 
 
 /**
  * Page returned for refused requests.
  */
-#define REQUEST_REFUSED_PAGE "<html><head><title>Request refused</title></head><body>Request refused (file exists?)</body></html>"
+#define REQUEST_REFUSED_PAGE \
+  "<html><head><title>Request refused</title></head><body>Request refused (file exists?)</body></html>"
 
 
 /**
  * Head of index page.
  */
-#define INDEX_PAGE_HEADER "<html>\n<head><title>Welcome</title></head>\n<body>\n"\
-   "<h1>Upload</h1>\n"\
-   "<form method=\"POST\" enctype=\"multipart/form-data\" action=\"/\">\n"\
-   "<dl><dt>Content type:</dt><dd>"\
-   "<input type=\"radio\" name=\"category\" value=\"books\">Book</input>"\
-   "<input type=\"radio\" name=\"category\" value=\"images\">Image</input>"\
-   "<input type=\"radio\" name=\"category\" value=\"music\">Music</input>"\
-   "<input type=\"radio\" name=\"category\" value=\"software\">Software</input>"\
-   "<input type=\"radio\" name=\"category\" value=\"videos\">Videos</input>\n"\
-   "<input type=\"radio\" name=\"category\" value=\"other\" checked>Other</input></dd>"\
-   "<dt>Language:</dt><dd>"\
-   "<input type=\"radio\" name=\"language\" value=\"no-lang\" checked>none</input>"\
-   "<input type=\"radio\" name=\"language\" value=\"en\">English</input>"\
-   "<input type=\"radio\" name=\"language\" value=\"de\">German</input>"\
-   "<input type=\"radio\" name=\"language\" value=\"fr\">French</input>"\
-   "<input type=\"radio\" name=\"language\" value=\"es\">Spanish</input></dd>\n"\
-   "<dt>File:</dt><dd>"\
-   "<input type=\"file\" name=\"upload\"/></dd></dl>"\
-   "<input type=\"submit\" value=\"Send!\"/>\n"\
-   "</form>\n"\
-   "<h1>Download</h1>\n"\
-   "<ol>\n"
+#define INDEX_PAGE_HEADER \
+  "<html>\n<head><title>Welcome</title></head>\n<body>\n" \
+  "<h1>Upload</h1>\n" \
+  "<form method=\"POST\" enctype=\"multipart/form-data\" action=\"/\">\n" \
+  "<dl><dt>Content type:</dt><dd>" \
+  "<input type=\"radio\" name=\"category\" value=\"books\">Book</input>" \
+  "<input type=\"radio\" name=\"category\" value=\"images\">Image</input>" \
+  "<input type=\"radio\" name=\"category\" value=\"music\">Music</input>" \
+  "<input type=\"radio\" name=\"category\" value=\"software\">Software</input>" \
+  "<input type=\"radio\" name=\"category\" value=\"videos\">Videos</input>\n" \
+  "<input type=\"radio\" name=\"category\" value=\"other\" checked>Other</input></dd>" \
+  "<dt>Language:</dt><dd>" \
+  "<input type=\"radio\" name=\"language\" value=\"no-lang\" checked>none</input>" \
+  "<input type=\"radio\" name=\"language\" value=\"en\">English</input>" \
+  "<input type=\"radio\" name=\"language\" value=\"de\">German</input>" \
+  "<input type=\"radio\" name=\"language\" value=\"fr\">French</input>" \
+  "<input type=\"radio\" name=\"language\" value=\"es\">Spanish</input></dd>\n" \
+  "<dt>File:</dt><dd>" \
+  "<input type=\"file\" name=\"upload\"/></dd></dl>" \
+  "<input type=\"submit\" value=\"Send!\"/>\n" \
+  "</form>\n" \
+  "<h1>Download</h1>\n" \
+  "<ol>\n"
 
 /**
  * Footer of index page.
@@ -124,16 +128,15 @@
  * NULL-terminated array of supported upload categories.  Should match HTML
  * in the form.
  */
-static const char * const categories[] =
-  {
-    "books",
-    "images",
-    "music",
-    "software",
-    "videos",
-    "other",
-    NULL,
-  };
+static const char *const categories[] = {
+  "books",
+  "images",
+  "music",
+  "software",
+  "videos",
+  "other",
+  NULL,
+};
 
 
 /**
@@ -157,15 +160,14 @@ struct Language
  * NULL-terminated array of supported upload categories.  Should match HTML
  * in the form.
  */
-static const struct Language languages[] =
-  {
-    { "no-lang", "No language specified" },
-    { "en", "English" },
-    { "de", "German" },
-    { "fr", "French" },
-    { "es", "Spanish" },
-    { NULL, NULL },
-  };
+static const struct Language languages[] = {
+  { "no-lang", "No language specified" },
+  { "en", "English" },
+  { "de", "German" },
+  { "fr", "French" },
+  { "es", "Spanish" },
+  { NULL, NULL },
+};
 
 
 /**
@@ -210,8 +212,8 @@ static void
 mark_as_html (struct MHD_Response *response)
 {
   (void) MHD_add_response_header (response,
-				  MHD_HTTP_HEADER_CONTENT_TYPE,
-				  "text/html");
+                                  MHD_HTTP_HEADER_CONTENT_TYPE,
+                                  "text/html");
 }
 
 
@@ -264,7 +266,7 @@ struct ResponseDataContext
  */
 static int
 list_directory (struct ResponseDataContext *rdc,
-		const char *dirname)
+                const char *dirname)
 {
   char fullname[PATH_MAX];
   struct stat sbuf;
@@ -274,35 +276,35 @@ list_directory (struct ResponseDataContext *rdc,
   if (NULL == (dir = opendir (dirname)))
     return MHD_NO;
   while (NULL != (de = readdir (dir)))
+  {
+    if ('.' == de->d_name[0])
+      continue;
+    if (sizeof (fullname) <= (unsigned int)
+        snprintf (fullname, sizeof (fullname),
+                  "%s/%s",
+                  dirname, de->d_name))
+      continue; /* ugh, file too long? how can this be!? */
+    if (0 != stat (fullname, &sbuf))
+      continue; /* ugh, failed to 'stat' */
+    if (! S_ISREG (sbuf.st_mode))
+      continue; /* not a regular file, skip */
+    if (rdc->off + 1024 > rdc->buf_len)
     {
-      if ('.' == de->d_name[0])
-	continue;
-      if (sizeof (fullname) <= (unsigned int)
-	  snprintf (fullname, sizeof (fullname),
-		    "%s/%s",
-		    dirname, de->d_name))
-	continue; /* ugh, file too long? how can this be!? */
-      if (0 != stat (fullname, &sbuf))
-	continue; /* ugh, failed to 'stat' */
-      if (! S_ISREG (sbuf.st_mode))
-	continue; /* not a regular file, skip */
-      if (rdc->off + 1024 > rdc->buf_len)
-	{
-	  void *r;
+      void *r;
 
-	  if ( (2 * rdc->buf_len + 1024) < rdc->buf_len)
-	    break; /* more than SIZE_T _index_ size? Too big for us */
-	  rdc->buf_len = 2 * rdc->buf_len + 1024;
-	  if (NULL == (r = realloc (rdc->buf, rdc->buf_len)))
-	    break; /* out of memory */
-	  rdc->buf = r;
-	}
-      rdc->off += snprintf (&rdc->buf[rdc->off],
-			    rdc->buf_len - rdc->off,
-			    "<li><a href=\"/%s\">%s</a></li>\n",
-			    fullname,
-			    de->d_name);
+      if ( (2 * rdc->buf_len + 1024) < rdc->buf_len)
+        break; /* more than SIZE_T _index_ size? Too big for us */
+      rdc->buf_len = 2 * rdc->buf_len + 1024;
+      if (NULL == (r = realloc (rdc->buf, rdc->buf_len)))
+        break; /* out of memory */
+      rdc->buf = r;
     }
+    rdc->off += snprintf (&rdc->buf[rdc->off],
+                          rdc->buf_len - rdc->off,
+                          "<li><a href=\"/%s\">%s</a></li>\n",
+                          fullname,
+                          de->d_name);
+  }
   (void) closedir (dir);
   return MHD_YES;
 }
@@ -326,65 +328,66 @@ update_directory ()
 
   rdc.buf_len = initial_allocation;
   if (NULL == (rdc.buf = malloc (rdc.buf_len)))
-    {
-      update_cached_response (NULL);
-      return;
-    }
+  {
+    update_cached_response (NULL);
+    return;
+  }
   rdc.off = snprintf (rdc.buf, rdc.buf_len,
-		      "%s",
-		      INDEX_PAGE_HEADER);
-  for (language_idx = 0; NULL != languages[language_idx].dirname; language_idx++)
+                      "%s",
+                      INDEX_PAGE_HEADER);
+  for (language_idx = 0; NULL != languages[language_idx].dirname;
+       language_idx++)
+  {
+    language = &languages[language_idx];
+
+    if (0 != stat (language->dirname, &sbuf))
+      continue; /* empty */
+    /* we ensured always +1k room, filenames are ~256 bytes,
+ so there is always still enough space for the header
+ without need for an additional reallocation check. */
+    rdc.off += snprintf (&rdc.buf[rdc.off], rdc.buf_len - rdc.off,
+                         "<h2>%s</h2>\n",
+                         language->longname);
+    for (category_idx = 0; NULL != categories[category_idx]; category_idx++)
     {
-      language = &languages[language_idx];
+      category = categories[category_idx];
+      snprintf (dir_name, sizeof (dir_name),
+                "%s/%s",
+                language->dirname,
+                category);
+      if (0 != stat (dir_name, &sbuf))
+        continue; /* empty */
 
-      if (0 != stat (language->dirname, &sbuf))
-	continue; /* empty */
       /* we ensured always +1k room, filenames are ~256 bytes,
-	 so there is always still enough space for the header
-	 without need for an additional reallocation check. */
+         so there is always still enough space for the header
+         without need for an additional reallocation check. */
       rdc.off += snprintf (&rdc.buf[rdc.off], rdc.buf_len - rdc.off,
-			   "<h2>%s</h2>\n",
-			   language->longname);
-      for (category_idx = 0; NULL != categories[category_idx]; category_idx++)
-	{
-	  category = categories[category_idx];
-	  snprintf (dir_name, sizeof (dir_name),
-		    "%s/%s",
-		    language->dirname,
-		    category);
-	  if (0 != stat (dir_name, &sbuf))
-	    continue; /* empty */
+                           "<h3>%s</h3>\n",
+                           category);
 
-	  /* we ensured always +1k room, filenames are ~256 bytes,
-	     so there is always still enough space for the header
-	     without need for an additional reallocation check. */
-	  rdc.off += snprintf (&rdc.buf[rdc.off], rdc.buf_len - rdc.off,
-			       "<h3>%s</h3>\n",
-			       category);
-
-	  if (MHD_NO == list_directory (&rdc, dir_name))
-	    {
-	      free (rdc.buf);
-	      update_cached_response (NULL);
-	      return;
-	    }
-	}
+      if (MHD_NO == list_directory (&rdc, dir_name))
+      {
+        free (rdc.buf);
+        update_cached_response (NULL);
+        return;
+      }
     }
+  }
   /* we ensured always +1k room, filenames are ~256 bytes,
      so there is always still enough space for the footer
      without need for a final reallocation check. */
   rdc.off += snprintf (&rdc.buf[rdc.off], rdc.buf_len - rdc.off,
-		       "%s",
-		       INDEX_PAGE_FOOTER);
+                       "%s",
+                       INDEX_PAGE_FOOTER);
   initial_allocation = rdc.buf_len; /* remember for next time */
   response = MHD_create_response_from_buffer (rdc.off,
-					      rdc.buf,
-					      MHD_RESPMEM_MUST_FREE);
+                                              rdc.buf,
+                                              MHD_RESPMEM_MUST_FREE);
   mark_as_html (response);
 #if FORCE_CLOSE
   (void) MHD_add_response_header (response,
-				  MHD_HTTP_HEADER_CONNECTION,
-				  "close");
+                                  MHD_HTTP_HEADER_CONNECTION,
+                                  "close");
 #endif
   update_cached_response (response);
 }
@@ -443,8 +446,8 @@ struct UploadContext
  */
 static int
 do_append (char **ret,
-	   const char *data,
-	   size_t size)
+           const char *data,
+           size_t size)
 {
   char *buf;
   size_t old_len;
@@ -456,15 +459,15 @@ do_append (char **ret,
   if (NULL == (buf = malloc (old_len + size + 1)))
     return MHD_NO;
   if (NULL != *ret)
-    {
-      memcpy (buf,
-	      *ret,
-	      old_len);
-      free (*ret);
-    }
+  {
+    memcpy (buf,
+            *ret,
+            old_len);
+    free (*ret);
+  }
   memcpy (&buf[old_len],
-	  data,
-	  size);
+          data,
+          size);
   buf[old_len + size] = '\0';
   *ret = buf;
   return MHD_YES;
@@ -492,119 +495,119 @@ do_append (char **ret,
  */
 static int
 process_upload_data (void *cls,
-		     enum MHD_ValueKind kind,
-		     const char *key,
-		     const char *filename,
-		     const char *content_type,
-		     const char *transfer_encoding,
-		     const char *data,
-		     uint64_t off,
-		     size_t size)
+                     enum MHD_ValueKind kind,
+                     const char *key,
+                     const char *filename,
+                     const char *content_type,
+                     const char *transfer_encoding,
+                     const char *data,
+                     uint64_t off,
+                     size_t size)
 {
   struct UploadContext *uc = cls;
   int i;
-  (void)kind;              /* Unused. Silent compiler warning. */
-  (void)content_type;      /* Unused. Silent compiler warning. */
-  (void)transfer_encoding; /* Unused. Silent compiler warning. */
-  (void)off;               /* Unused. Silent compiler warning. */
+  (void) kind;              /* Unused. Silent compiler warning. */
+  (void) content_type;      /* Unused. Silent compiler warning. */
+  (void) transfer_encoding; /* Unused. Silent compiler warning. */
+  (void) off;               /* Unused. Silent compiler warning. */
 
   if (0 == strcmp (key, "category"))
     return do_append (&uc->category, data, size);
   if (0 == strcmp (key, "language"))
     return do_append (&uc->language, data, size);
   if (0 != strcmp (key, "upload"))
-    {
-      fprintf (stderr,
-	       "Ignoring unexpected form value `%s'\n",
-	       key);
-      return MHD_YES; /* ignore */
-    }
+  {
+    fprintf (stderr,
+             "Ignoring unexpected form value `%s'\n",
+             key);
+    return MHD_YES;   /* ignore */
+  }
   if (NULL == filename)
-    {
-      fprintf (stderr, "No filename, aborting upload\n");
-      return MHD_NO; /* no filename, error */
-    }
+  {
+    fprintf (stderr, "No filename, aborting upload\n");
+    return MHD_NO;   /* no filename, error */
+  }
   if ( (NULL == uc->category) ||
        (NULL == uc->language) )
+  {
+    fprintf (stderr,
+             "Missing form data for upload `%s'\n",
+             filename);
+    uc->response = request_refused_response;
+    return MHD_NO;
+  }
+  if (-1 == uc->fd)
+  {
+    char fn[PATH_MAX];
+
+    if ( (NULL != strstr (filename, "..")) ||
+         (NULL != strchr (filename, '/')) ||
+         (NULL != strchr (filename, '\\')) )
     {
-      fprintf (stderr,
-	       "Missing form data for upload `%s'\n",
-	       filename);
       uc->response = request_refused_response;
       return MHD_NO;
     }
-  if (-1 == uc->fd)
-    {
-      char fn[PATH_MAX];
-
-      if ( (NULL != strstr (filename, "..")) ||
-	   (NULL != strchr (filename, '/')) ||
-	   (NULL != strchr (filename, '\\')) )
-	{
-	  uc->response = request_refused_response;
-	  return MHD_NO;
-	}
-      /* create directories -- if they don't exist already */
+    /* create directories -- if they don't exist already */
 #ifdef WINDOWS
-      (void) mkdir (uc->language);
+    (void) mkdir (uc->language);
 #else
-      (void) mkdir (uc->language, S_IRWXU);
+    (void) mkdir (uc->language, S_IRWXU);
 #endif
-      snprintf (fn, sizeof (fn),
-		"%s/%s",
-		uc->language,
-		uc->category);
+    snprintf (fn, sizeof (fn),
+              "%s/%s",
+              uc->language,
+              uc->category);
 #ifdef WINDOWS
-      (void) mkdir (fn);
+    (void) mkdir (fn);
 #else
-      (void) mkdir (fn, S_IRWXU);
+    (void) mkdir (fn, S_IRWXU);
 #endif
-      /* open file */
-      snprintf (fn, sizeof (fn),
-		"%s/%s/%s",
-		uc->language,
-		uc->category,
-		filename);
-      for (i=strlen (fn)-1;i>=0;i--)
-	if (! isprint ((unsigned char) fn[i]))
-	  fn[i] = '_';
-      uc->fd = open (fn,
-		     O_CREAT | O_EXCL
+    /* open file */
+    snprintf (fn, sizeof (fn),
+              "%s/%s/%s",
+              uc->language,
+              uc->category,
+              filename);
+    for (i = strlen (fn) - 1; i>=0; i--)
+      if (! isprint ((unsigned char) fn[i]))
+        fn[i] = '_';
+    uc->fd = open (fn,
+                   O_CREAT | O_EXCL
 #if O_LARGEFILE
-		     | O_LARGEFILE
+                   | O_LARGEFILE
 #endif
-		     | O_WRONLY,
-		     S_IRUSR | S_IWUSR);
-      if (-1 == uc->fd)
-	{
-	  fprintf (stderr,
-		   "Error opening file `%s' for upload: %s\n",
-		   fn,
-		   strerror (errno));
-	  uc->response = request_refused_response;
-	  return MHD_NO;
-	}
-      uc->filename = strdup (fn);
-    }
-  if ( (0 != size) &&
-       (size != (size_t) write (uc->fd, data, size)) )
+                   | O_WRONLY,
+                   S_IRUSR | S_IWUSR);
+    if (-1 == uc->fd)
     {
-      /* write failed; likely: disk full */
       fprintf (stderr,
-	       "Error writing to file `%s': %s\n",
-	       uc->filename,
-	       strerror (errno));
-      uc->response = internal_error_response;
-      (void) close (uc->fd);
-      uc->fd = -1;
-      if (NULL != uc->filename)
-	{
-	  unlink (uc->filename);
-	  free (uc->filename);
-	  uc->filename = NULL;
-	}
+               "Error opening file `%s' for upload: %s\n",
+               fn,
+               strerror (errno));
+      uc->response = request_refused_response;
       return MHD_NO;
     }
+    uc->filename = strdup (fn);
+  }
+  if ( (0 != size) &&
+       (size != (size_t) write (uc->fd, data, size)) )
+  {
+    /* write failed; likely: disk full */
+    fprintf (stderr,
+             "Error writing to file `%s': %s\n",
+             uc->filename,
+             strerror (errno));
+    uc->response = internal_error_response;
+    (void) close (uc->fd);
+    uc->fd = -1;
+    if (NULL != uc->filename)
+    {
+      unlink (uc->filename);
+      free (uc->filename);
+      uc->filename = NULL;
+    }
+    return MHD_NO;
+  }
   return MHD_YES;
 }
 
@@ -622,32 +625,32 @@ process_upload_data (void *cls,
  */
 static void
 response_completed_callback (void *cls,
-			     struct MHD_Connection *connection,
-			     void **con_cls,
-			     enum MHD_RequestTerminationCode toe)
+                             struct MHD_Connection *connection,
+                             void **con_cls,
+                             enum MHD_RequestTerminationCode toe)
 {
   struct UploadContext *uc = *con_cls;
-  (void)cls;         /* Unused. Silent compiler warning. */
-  (void)connection;  /* Unused. Silent compiler warning. */
-  (void)toe;         /* Unused. Silent compiler warning. */
+  (void) cls;         /* Unused. Silent compiler warning. */
+  (void) connection;  /* Unused. Silent compiler warning. */
+  (void) toe;         /* Unused. Silent compiler warning. */
 
   if (NULL == uc)
     return; /* this request wasn't an upload request */
   if (NULL != uc->pp)
-    {
-      MHD_destroy_post_processor (uc->pp);
-      uc->pp = NULL;
-    }
+  {
+    MHD_destroy_post_processor (uc->pp);
+    uc->pp = NULL;
+  }
   if (-1 != uc->fd)
   {
     (void) close (uc->fd);
     if (NULL != uc->filename)
-      {
-	fprintf (stderr,
-		 "Upload of file `%s' failed (incomplete or aborted), removing file.\n",
-		 uc->filename);
-	(void) unlink (uc->filename);
-      }
+    {
+      fprintf (stderr,
+               "Upload of file `%s' failed (incomplete or aborted), removing file.\n",
+               uc->filename);
+      (void) unlink (uc->filename);
+    }
   }
   if (NULL != uc->filename)
     free (uc->filename);
@@ -669,12 +672,12 @@ return_directory_response (struct MHD_Connection *connection)
   (void) pthread_mutex_lock (&mutex);
   if (NULL == cached_directory_response)
     ret = MHD_queue_response (connection,
-			      MHD_HTTP_INTERNAL_SERVER_ERROR,
-			      internal_error_response);
+                              MHD_HTTP_INTERNAL_SERVER_ERROR,
+                              internal_error_response);
   else
     ret = MHD_queue_response (connection,
-			      MHD_HTTP_OK,
-			      cached_directory_response);
+                              MHD_HTTP_OK,
+                              cached_directory_response);
   (void) pthread_mutex_unlock (&mutex);
   return ret;
 }
@@ -695,12 +698,12 @@ return_directory_response (struct MHD_Connection *connection)
  */
 static int
 generate_page (void *cls,
-	       struct MHD_Connection *connection,
-	       const char *url,
-	       const char *method,
-	       const char *version,
-	       const char *upload_data,
-	       size_t *upload_data_size, void **ptr)
+               struct MHD_Connection *connection,
+               const char *url,
+               const char *method,
+               const char *version,
+               const char *upload_data,
+               size_t *upload_data_size, void **ptr)
 {
   struct MHD_Response *response;
   int ret;
@@ -710,117 +713,117 @@ generate_page (void *cls,
   (void) version;           /* Unused. Silent compiler warning. */
 
   if (0 != strcmp (url, "/"))
+  {
+    /* should be file download */
+#ifdef MHD_HAVE_LIBMAGIC
+    char file_data[MAGIC_HEADER_SIZE];
+    ssize_t got;
+#endif /* MHD_HAVE_LIBMAGIC */
+    const char *mime;
+
+    if ( (0 != strcmp (method, MHD_HTTP_METHOD_GET)) &&
+         (0 != strcmp (method, MHD_HTTP_METHOD_HEAD)) )
+      return MHD_NO;    /* unexpected method (we're not polite...) */
+    fd = -1;
+    if ( (NULL == strstr (&url[1], "..")) &&
+         ('/' != url[1]) )
     {
-      /* should be file download */
-#ifdef MHD_HAVE_LIBMAGIC
-      char file_data[MAGIC_HEADER_SIZE];
-      ssize_t got;
-#endif /* MHD_HAVE_LIBMAGIC */
-      const char *mime;
-
-      if ( (0 != strcmp (method, MHD_HTTP_METHOD_GET)) &&
-           (0 != strcmp (method, MHD_HTTP_METHOD_HEAD)) )
-        return MHD_NO;  /* unexpected method (we're not polite...) */
-      fd = -1;
-      if ( (NULL == strstr (&url[1], "..")) &&
-	   ('/' != url[1]) )
-        {
-          fd = open (&url[1], O_RDONLY);
-          if ( (-1 != fd) &&
-               ( (0 != fstat (fd, &buf)) ||
-                 (! S_ISREG (buf.st_mode)) ) )
-            {
-              (void) close (fd);
-              fd = -1;
-            }
-        }
-      if (-1 == fd)
-	return MHD_queue_response (connection,
-				   MHD_HTTP_NOT_FOUND,
-				   file_not_found_response);
-#ifdef MHD_HAVE_LIBMAGIC
-      /* read beginning of the file to determine mime type  */
-      got = read (fd, file_data, sizeof (file_data));
-      (void) lseek (fd, 0, SEEK_SET);
-      if (-1 != got)
-	mime = magic_buffer (magic, file_data, got);
-      else
-#endif /* MHD_HAVE_LIBMAGIC */
-	mime = NULL;
-
-      if (NULL == (response = MHD_create_response_from_fd (buf.st_size,
-							   fd)))
-	{
-	  /* internal error (i.e. out of memory) */
-	  (void) close (fd);
-	  return MHD_NO;
-	}
-
-      /* add mime type if we had one */
-      if (NULL != mime)
-	(void) MHD_add_response_header (response,
-					MHD_HTTP_HEADER_CONTENT_TYPE,
-					mime);
-      ret = MHD_queue_response (connection,
-				MHD_HTTP_OK,
-				response);
-      MHD_destroy_response (response);
-      return ret;
+      fd = open (&url[1], O_RDONLY);
+      if ( (-1 != fd) &&
+           ( (0 != fstat (fd, &buf)) ||
+             (! S_ISREG (buf.st_mode)) ) )
+      {
+        (void) close (fd);
+        fd = -1;
+      }
     }
+    if (-1 == fd)
+      return MHD_queue_response (connection,
+                                 MHD_HTTP_NOT_FOUND,
+                                 file_not_found_response);
+#ifdef MHD_HAVE_LIBMAGIC
+    /* read beginning of the file to determine mime type  */
+    got = read (fd, file_data, sizeof (file_data));
+    (void) lseek (fd, 0, SEEK_SET);
+    if (-1 != got)
+      mime = magic_buffer (magic, file_data, got);
+    else
+#endif /* MHD_HAVE_LIBMAGIC */
+    mime = NULL;
+
+    if (NULL == (response = MHD_create_response_from_fd (buf.st_size,
+                                                         fd)))
+    {
+      /* internal error (i.e. out of memory) */
+      (void) close (fd);
+      return MHD_NO;
+    }
+
+    /* add mime type if we had one */
+    if (NULL != mime)
+      (void) MHD_add_response_header (response,
+                                      MHD_HTTP_HEADER_CONTENT_TYPE,
+                                      mime);
+    ret = MHD_queue_response (connection,
+                              MHD_HTTP_OK,
+                              response);
+    MHD_destroy_response (response);
+    return ret;
+  }
 
   if (0 == strcmp (method, MHD_HTTP_METHOD_POST))
-    {
-      /* upload! */
-      struct UploadContext *uc = *ptr;
+  {
+    /* upload! */
+    struct UploadContext *uc = *ptr;
 
-      if (NULL == uc)
-	{
-	  if (NULL == (uc = malloc (sizeof (struct UploadContext))))
-	    return MHD_NO; /* out of memory, close connection */
-	  memset (uc, 0, sizeof (struct UploadContext));
-          uc->fd = -1;
-	  uc->connection = connection;
-	  uc->pp = MHD_create_post_processor (connection,
-					      64 * 1024 /* buffer size */,
-					      &process_upload_data, uc);
-	  if (NULL == uc->pp)
-	    {
-	      /* out of memory, close connection */
-	      free (uc);
-	      return MHD_NO;
-	    }
-	  *ptr = uc;
-	  return MHD_YES;
-	}
-      if (0 != *upload_data_size)
-	{
-	  if (NULL == uc->response)
-	    (void) MHD_post_process (uc->pp,
-				     upload_data,
-				     *upload_data_size);
-	  *upload_data_size = 0;
-	  return MHD_YES;
-	}
-      /* end of upload, finish it! */
-      MHD_destroy_post_processor (uc->pp);
-      uc->pp = NULL;
-      if (-1 != uc->fd)
-	{
-	  close (uc->fd);
-	  uc->fd = -1;
-	}
-      if (NULL != uc->response)
-	{
-	  return MHD_queue_response (connection,
-				     MHD_HTTP_FORBIDDEN,
-				     uc->response);
-	}
-      else
-	{
-	  update_directory ();
-	  return return_directory_response (connection);
-	}
+    if (NULL == uc)
+    {
+      if (NULL == (uc = malloc (sizeof (struct UploadContext))))
+        return MHD_NO; /* out of memory, close connection */
+      memset (uc, 0, sizeof (struct UploadContext));
+      uc->fd = -1;
+      uc->connection = connection;
+      uc->pp = MHD_create_post_processor (connection,
+                                          64 * 1024 /* buffer size */,
+                                          &process_upload_data, uc);
+      if (NULL == uc->pp)
+      {
+        /* out of memory, close connection */
+        free (uc);
+        return MHD_NO;
+      }
+      *ptr = uc;
+      return MHD_YES;
     }
+    if (0 != *upload_data_size)
+    {
+      if (NULL == uc->response)
+        (void) MHD_post_process (uc->pp,
+                                 upload_data,
+                                 *upload_data_size);
+      *upload_data_size = 0;
+      return MHD_YES;
+    }
+    /* end of upload, finish it! */
+    MHD_destroy_post_processor (uc->pp);
+    uc->pp = NULL;
+    if (-1 != uc->fd)
+    {
+      close (uc->fd);
+      uc->fd = -1;
+    }
+    if (NULL != uc->response)
+    {
+      return MHD_queue_response (connection,
+                                 MHD_HTTP_FORBIDDEN,
+                                 uc->response);
+    }
+    else
+    {
+      update_directory ();
+      return return_directory_response (connection);
+    }
+  }
   if ( (0 == strcmp (method, MHD_HTTP_METHOD_GET)) ||
        (0 == strcmp (method, MHD_HTTP_METHOD_HEAD)) )
   {
@@ -829,8 +832,8 @@ generate_page (void *cls,
 
   /* unexpected request, refuse */
   return MHD_queue_response (connection,
-			     MHD_HTTP_FORBIDDEN,
-			     request_refused_response);
+                             MHD_HTTP_FORBIDDEN,
+                             request_refused_response);
 }
 
 
@@ -843,7 +846,7 @@ generate_page (void *cls,
 static void
 catcher (int sig)
 {
-  (void)sig;	/* Unused. Silent compiler warning. */
+  (void) sig;  /* Unused. Silent compiler warning. */
   /* do nothing */
 }
 
@@ -868,6 +871,8 @@ ignore_sigpipe ()
     fprintf (stderr,
              "Failed to install SIGPIPE handler: %s\n", strerror (errno));
 }
+
+
 #endif
 
 
@@ -889,11 +894,11 @@ main (int argc, char *const *argv)
   if ( (argc != 2) ||
        (1 != sscanf (argv[1], "%u", &port)) ||
        (UINT16_MAX < port) )
-    {
-      fprintf (stderr,
-	       "%s PORT\n", argv[0]);
-      return 1;
-    }
+  {
+    fprintf (stderr,
+             "%s PORT\n", argv[0]);
+    return 1;
+  }
 #ifndef MINGW
   ignore_sigpipe ();
 #endif
@@ -903,31 +908,42 @@ main (int argc, char *const *argv)
 #endif /* MHD_HAVE_LIBMAGIC */
 
   (void) pthread_mutex_init (&mutex, NULL);
-  file_not_found_response = MHD_create_response_from_buffer (strlen (FILE_NOT_FOUND_PAGE),
-							     (void *) FILE_NOT_FOUND_PAGE,
-							     MHD_RESPMEM_PERSISTENT);
+  file_not_found_response = MHD_create_response_from_buffer (strlen (
+                                                               FILE_NOT_FOUND_PAGE),
+                                                             (void *)
+                                                             FILE_NOT_FOUND_PAGE,
+                                                             MHD_RESPMEM_PERSISTENT);
   mark_as_html (file_not_found_response);
-  request_refused_response = MHD_create_response_from_buffer (strlen (REQUEST_REFUSED_PAGE),
-							     (void *) REQUEST_REFUSED_PAGE,
-							     MHD_RESPMEM_PERSISTENT);
+  request_refused_response = MHD_create_response_from_buffer (strlen (
+                                                                REQUEST_REFUSED_PAGE),
+                                                              (void *)
+                                                              REQUEST_REFUSED_PAGE,
+                                                              MHD_RESPMEM_PERSISTENT);
   mark_as_html (request_refused_response);
-  internal_error_response = MHD_create_response_from_buffer (strlen (INTERNAL_ERROR_PAGE),
-							     (void *) INTERNAL_ERROR_PAGE,
-							     MHD_RESPMEM_PERSISTENT);
+  internal_error_response = MHD_create_response_from_buffer (strlen (
+                                                               INTERNAL_ERROR_PAGE),
+                                                             (void *)
+                                                             INTERNAL_ERROR_PAGE,
+                                                             MHD_RESPMEM_PERSISTENT);
   mark_as_html (internal_error_response);
   update_directory ();
-  d = MHD_start_daemon (MHD_USE_AUTO | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
+  d = MHD_start_daemon (MHD_USE_AUTO | MHD_USE_INTERNAL_POLLING_THREAD
+                        | MHD_USE_ERROR_LOG,
                         port,
                         NULL, NULL,
-			&generate_page, NULL,
-			MHD_OPTION_CONNECTION_MEMORY_LIMIT, (size_t) (256 * 1024),
+                        &generate_page, NULL,
+                        MHD_OPTION_CONNECTION_MEMORY_LIMIT, (size_t) (256
+                                                                      * 1024),
 #if PRODUCTION
-			MHD_OPTION_PER_IP_CONNECTION_LIMIT, (unsigned int) (64),
+                        MHD_OPTION_PER_IP_CONNECTION_LIMIT, (unsigned int) (64),
 #endif
-			MHD_OPTION_CONNECTION_TIMEOUT, (unsigned int) (120 /* seconds */),
-			MHD_OPTION_THREAD_POOL_SIZE, (unsigned int) NUMBER_OF_THREADS,
-			MHD_OPTION_NOTIFY_COMPLETED, &response_completed_callback, NULL,
-			MHD_OPTION_END);
+                        MHD_OPTION_CONNECTION_TIMEOUT, (unsigned
+                                                        int) (120 /* seconds */),
+                        MHD_OPTION_THREAD_POOL_SIZE, (unsigned
+                                                      int) NUMBER_OF_THREADS,
+                        MHD_OPTION_NOTIFY_COMPLETED,
+                        &response_completed_callback, NULL,
+                        MHD_OPTION_END);
   if (NULL == d)
     return 1;
   fprintf (stderr, "HTTP server running. Press ENTER to stop the server\n");
@@ -944,4 +960,5 @@ main (int argc, char *const *argv)
   return 0;
 }
 
+
 /* end of demo.c */
