@@ -31,7 +31,8 @@
 
 #define TIMEOUT_INFINITE -1
 
-struct Request {
+struct Request
+{
   struct MHD_Connection *connection;
   int timerfd;
 };
@@ -52,10 +53,12 @@ ahc_echo (void *cls,
 {
   struct MHD_Response *response;
   int ret;
-  struct Request* req;
+  struct Request*req;
   struct itimerspec ts;
 
+  (void) cls;
   (void) url;               /* Unused. Silence compiler warning. */
+  (void) method;
   (void) version;           /* Unused. Silence compiler warning. */
   (void) upload_data;       /* Unused. Silence compiler warning. */
   (void) upload_data_size;  /* Unused. Silence compiler warning. */
@@ -87,29 +90,29 @@ ahc_echo (void *cls,
     return ret;
   }
   /* create timer and suspend connection */
-  req->timerfd = timerfd_create(CLOCK_MONOTONIC, TFD_NONBLOCK);
+  req->timerfd = timerfd_create (CLOCK_MONOTONIC, TFD_NONBLOCK);
   if (-1 == req->timerfd)
-    {
-      printf("timerfd_create: %s", strerror(errno));
-      return MHD_NO;
-    }
+  {
+    printf ("timerfd_create: %s", strerror (errno));
+    return MHD_NO;
+  }
   evt.events = EPOLLIN;
   evt.data.ptr = req;
-  if (-1 == epoll_ctl(epfd, EPOLL_CTL_ADD, req->timerfd, &evt))
-    {
-      printf("epoll_ctl: %s", strerror(errno));
-      return MHD_NO;
-    }
+  if (-1 == epoll_ctl (epfd, EPOLL_CTL_ADD, req->timerfd, &evt))
+  {
+    printf ("epoll_ctl: %s", strerror (errno));
+    return MHD_NO;
+  }
   ts.it_value.tv_sec = 1;
   ts.it_value.tv_nsec = 0;
   ts.it_interval.tv_sec = 0;
   ts.it_interval.tv_nsec = 0;
-  if (-1 == timerfd_settime(req->timerfd, 0, &ts, NULL))
-    {
-      printf("timerfd_settime: %s", strerror(errno));
-      return MHD_NO;
-    }
-  MHD_suspend_connection(connection);
+  if (-1 == timerfd_settime (req->timerfd, 0, &ts, NULL))
+  {
+    printf ("timerfd_settime: %s", strerror (errno));
+    return MHD_NO;
+  }
+  MHD_suspend_connection (connection);
   return MHD_YES;
 }
 
@@ -122,10 +125,13 @@ connection_done (void *cls,
 {
   struct Request *req = *con_cls;
 
+  (void) cls;
+  (void) connection;
+  (void) toe;
   if (-1 != req->timerfd)
     if (0 != close (req->timerfd))
       abort ();
-  free(req);
+  free (req);
 }
 
 
@@ -134,17 +140,17 @@ main (int argc,
       char *const *argv)
 {
   struct MHD_Daemon *d;
-  const union MHD_DaemonInfo * info;
+  const union MHD_DaemonInfo *info;
   int current_event_count;
   struct epoll_event events_list[1];
   struct Request *req;
   uint64_t timer_expirations;
 
   if (argc != 2)
-    {
-      printf ("%s PORT\n", argv[0]);
-      return 1;
-    }
+  {
+    printf ("%s PORT\n", argv[0]);
+    return 1;
+  }
   d = MHD_start_daemon (MHD_USE_EPOLL | MHD_ALLOW_SUSPEND_RESUME,
                         atoi (argv[1]),
                         NULL, NULL, &ahc_echo, NULL,
@@ -153,17 +159,17 @@ main (int argc,
   if (d == NULL)
     return 1;
 
-  info = MHD_get_daemon_info(d, MHD_DAEMON_INFO_EPOLL_FD);
+  info = MHD_get_daemon_info (d, MHD_DAEMON_INFO_EPOLL_FD);
   if (info == NULL)
     return 1;
 
-  epfd = epoll_create1(EPOLL_CLOEXEC);
+  epfd = epoll_create1 (EPOLL_CLOEXEC);
   if (-1 == epfd)
     return 1;
 
   evt.events = EPOLLIN;
   evt.data.ptr = NULL;
-  if (-1 == epoll_ctl(epfd, EPOLL_CTL_ADD, info->epoll_fd, &evt))
+  if (-1 == epoll_ctl (epfd, EPOLL_CTL_ADD, info->epoll_fd, &evt))
     return 1;
 
   while (1)
@@ -177,7 +183,7 @@ main (int argc,
       timeout = TIMEOUT_INFINITE;
     else
       timeout = (to < INT_MAX - 1) ? (int) to : (INT_MAX - 1);
-    current_event_count = epoll_wait(epfd, events_list, 1, timeout);
+    current_event_count = epoll_wait (epfd, events_list, 1, timeout);
 
     if (1 == current_event_count)
     {
@@ -186,12 +192,13 @@ main (int argc,
         /*  A timer has timed out */
         req = events_list[0].data.ptr;
         /* read from the fd so the system knows we heard the notice */
-        if (-1 == read(req->timerfd, &timer_expirations, sizeof(timer_expirations)))
+        if (-1 == read (req->timerfd, &timer_expirations,
+                        sizeof(timer_expirations)))
         {
           return 1;
         }
         /*  Now resume the connection */
-        MHD_resume_connection(req->connection);
+        MHD_resume_connection (req->connection);
       }
     }
     else if (0 == current_event_count)
@@ -203,7 +210,7 @@ main (int argc,
       /* error */
       return 1;
     }
-    if (! MHD_run(d))
+    if (! MHD_run (d))
       return 1;
   }
 
