@@ -139,6 +139,8 @@ gnutlscli_connect (int *sock,
   }
   _exit (1);
 }
+
+
 #endif /* HTTPS_SUPPORT && HAVE_FORK && HAVE_WAITPID */
 
 
@@ -296,14 +298,14 @@ wr_connect (struct wr_socket *s,
      * it require processing on MHD side and
      * when testing with "external" polling,
      * test will call MHD processing only
-     * after return from wr_connect(). */
-    s->tls_connected = 0;
+     * after return from wr_connect(). */s->tls_connected = 0;
     return 0;
   }
 #endif /* HTTPS_SUPPORT */
   return -1;
 }
 
+
 #ifdef HTTPS_SUPPORT
 /* Only to be called from wr_send() and wr_recv() ! */
 static bool
@@ -318,6 +320,8 @@ wr_handshake (struct wr_socket *s)
     MHD_socket_set_error_ (MHD_SCKT_ECONNABORTED_); /* hard error */
   return s->tls_connected;
 }
+
+
 #endif /* HTTPS_SUPPORT */
 
 
@@ -924,6 +928,7 @@ run_mhd_select_loop (struct MHD_Daemon *daemon)
   }
 }
 
+
 #ifdef HAVE_POLL
 
 /**
@@ -937,6 +942,8 @@ run_mhd_poll_loop (struct MHD_Daemon *daemon)
   (void) daemon; /* Unused. Silent compiler warning. */
   abort (); /* currently not implementable with existing MHD API */
 }
+
+
 #endif /* HAVE_POLL */
 
 
@@ -983,6 +990,8 @@ run_mhd_epoll_loop (struct MHD_Daemon *daemon)
     MHD_run (daemon);
   }
 }
+
+
 #endif /* EPOLL_SUPPORT */
 
 /**
@@ -1076,7 +1085,7 @@ test_upgrade (int flags,
   if ( (NULL == dinfo) ||
        (0 == dinfo->port) )
     abort ();
-  if (! test_tls ||(TLS_LIB_GNUTLS == use_tls_tool))
+  if (! test_tls || (TLS_LIB_GNUTLS == use_tls_tool))
   {
     sock = test_tls ? wr_create_tls_sckt () : wr_create_plain_sckt ();
     if (NULL == sock)
@@ -1134,7 +1143,7 @@ test_upgrade (int flags,
   pthread_join (pt,
                 NULL);
 #if defined(HTTPS_SUPPORT) && defined(HAVE_FORK) && defined(HAVE_WAITPID)
-  if (test_tls &&(TLS_LIB_GNUTLS != use_tls_tool))
+  if (test_tls && (TLS_LIB_GNUTLS != use_tls_tool))
     waitpid (pid, NULL, 0);
 #endif /* HTTPS_SUPPORT && HAVE_FORK && HAVE_WAITPID */
   MHD_stop_daemon (d);
