@@ -32,25 +32,27 @@
 #define DEBUG_HTTPS_TEST 0
 #define CURL_VERBOS_LEVEL 0
 
-#define DEAMON_TEST_PORT 4233
-
 #define test_data "Hello World\n"
 #define ca_cert_file_name "tmp_ca_cert.pem"
 
-#define EMPTY_PAGE "<html><head><title>Empty page</title></head><body>Empty page</body></html>"
-#define PAGE_NOT_FOUND "<html><head><title>File not found</title></head><body>File not found</body></html>"
+#define EMPTY_PAGE \
+  "<html><head><title>Empty page</title></head><body>Empty page</body></html>"
+#define PAGE_NOT_FOUND \
+  "<html><head><title>File not found</title></head><body>File not found</body></html>"
 
 #define MHD_E_MEM "Error: memory error\n"
 #define MHD_E_SERVER_INIT "Error: failed to start server\n"
 #define MHD_E_TEST_FILE_CREAT "Error: failed to setup test file\n"
 #define MHD_E_CERT_FILE_CREAT "Error: failed to setup test certificate\n"
 #define MHD_E_KEY_FILE_CREAT "Error: failed to setup test certificate\n"
-#define MHD_E_FAILED_TO_CONNECT "Error: server connection could not be established\n"
+#define MHD_E_FAILED_TO_CONNECT \
+  "Error: server connection could not be established\n"
 
 /* TODO rm if unused */
 struct https_test_data
 {
   void *cls;
+  int port;
   const char *cipher_suite;
   int proto_version;
 };
@@ -69,24 +71,29 @@ struct CipherDef
 };
 
 
-int curl_check_version (const char *req_version, ...);
-int curl_uses_nss_ssl ();
+int
+curl_check_version (const char *req_version, ...);
+
+int
+curl_uses_nss_ssl (void);
 
 
 FILE *
-setup_ca_cert ();
+setup_ca_cert (void);
 
 /**
  * perform cURL request for file
  */
 int
-test_daemon_get (void * cls,
-		 const char *cipher_suite, int proto_version,
+test_daemon_get (void *cls,
+                 const char *cipher_suite, int proto_version,
                  int port, int ver_peer);
 
-void print_test_result (int test_outcome, char *test_name);
+void
+print_test_result (int test_outcome, char *test_name);
 
-size_t copyBuffer (void *ptr, size_t size, size_t nmemb, void *ctx);
+size_t
+copyBuffer (void *ptr, size_t size, size_t nmemb, void *ctx);
 
 int
 http_ahc (void *cls, struct MHD_Connection *connection,
@@ -103,39 +110,51 @@ http_dummy_ahc (void *cls, struct MHD_Connection *connection,
 /**
  * compile test file url pointing to the current running directory path
  *
- * @param url - char buffer into which the url is compiled
+ * @param[out] url - char buffer into which the url is compiled
+ * @param url_len number of bytes available in @a url
  * @param port port to use for the test
  * @return -1 on error
  */
-int gen_test_file_url (char *url, int port);
+int
+gen_test_file_url (char *url,
+                   size_t url_len,
+                   int port);
 
 int
 send_curl_req (char *url, struct CBC *cbc, const char *cipher_suite,
                int proto_version);
 
 int
-test_https_transfer (void *cls, const char *cipher_suite, int proto_version);
+test_https_transfer (void *cls, int port, const char *cipher_suite, int
+                     proto_version);
 
 int
-setup_testcase (struct MHD_Daemon **d, int daemon_flags, va_list arg_list);
+setup_testcase (struct MHD_Daemon **d, int port, int daemon_flags, va_list
+                arg_list);
+
+void
+teardown_testcase (struct MHD_Daemon *d);
 
-void teardown_testcase (struct MHD_Daemon *d);
 
 int
-setup_session (gnutls_session_t * session,
-               gnutls_datum_t * key,
-               gnutls_datum_t * cert,
-               gnutls_certificate_credentials_t * xcred);
+setup_session (gnutls_session_t *session,
+               gnutls_datum_t *key,
+               gnutls_datum_t *cert,
+               gnutls_certificate_credentials_t *xcred);
 
 int
 teardown_session (gnutls_session_t session,
-                  gnutls_datum_t * key,
-                  gnutls_datum_t * cert,
+                  gnutls_datum_t *key,
+                  gnutls_datum_t *cert,
                   gnutls_certificate_credentials_t xcred);
 
 int
 test_wrap (const char *test_name, int
-           (*test_function) (void * cls, const char *cipher_suite,
-                             int proto_version), void *test_function_cls,
+           (*test_function)(void *cls, int port, const char *cipher_suite,
+                            int proto_version), void *cls,
+           int port,
            int daemon_flags, const char *cipher_suite, int proto_version, ...);
+
+int testsuite_curl_global_init (void);
+
 #endif /* TLS_TEST_COMMON_H_ */
