@@ -196,7 +196,7 @@ testInternalPost ()
   {
     const union MHD_DaemonInfo *dinfo;
     dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-    if ((NULL == dinfo) ||(0 == dinfo->port) )
+    if ((NULL == dinfo) || (0 == dinfo->port) )
     {
       MHD_stop_daemon (d); return 32;
     }
@@ -239,6 +239,7 @@ testInternalPost ()
   return 0;
 }
 
+
 static int
 testMultithreadedPost ()
 {
@@ -272,7 +273,7 @@ testMultithreadedPost ()
   {
     const union MHD_DaemonInfo *dinfo;
     dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-    if ((NULL == dinfo) ||(0 == dinfo->port) )
+    if ((NULL == dinfo) || (0 == dinfo->port) )
     {
       MHD_stop_daemon (d); return 32;
     }
@@ -315,6 +316,7 @@ testMultithreadedPost ()
   return 0;
 }
 
+
 static int
 testMultithreadedPoolPost ()
 {
@@ -348,7 +350,7 @@ testMultithreadedPoolPost ()
   {
     const union MHD_DaemonInfo *dinfo;
     dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-    if ((NULL == dinfo) ||(0 == dinfo->port) )
+    if ((NULL == dinfo) || (0 == dinfo->port) )
     {
       MHD_stop_daemon (d); return 32;
     }
@@ -391,6 +393,7 @@ testMultithreadedPoolPost ()
   return 0;
 }
 
+
 static int
 testExternalPost ()
 {
@@ -438,7 +441,7 @@ testExternalPost ()
   {
     const union MHD_DaemonInfo *dinfo;
     dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-    if ((NULL == dinfo) ||(0 == dinfo->port) )
+    if ((NULL == dinfo) || (0 == dinfo->port) )
     {
       MHD_stop_daemon (d); return 32;
     }
@@ -514,9 +517,10 @@ testExternalPost ()
       if (EINTR != errno)
         abort ();
 #else
-      if ((WSAEINVAL != WSAGetLastError ()) ||(0 != rs.fd_count) ||(0 !=
-                                                                    ws.fd_count)
-          ||(0 != es.fd_count) )
+      if ((WSAEINVAL != WSAGetLastError ()) || (0 != rs.fd_count) || (0 !=
+                                                                      ws.
+                                                                      fd_count)
+          || (0 != es.fd_count) )
         abort ();
       Sleep (1000);
 #endif
@@ -599,6 +603,7 @@ ahc_cancel (void *cls,
   }
 }
 
+
 struct CRBC
 {
   const char *buffer;
@@ -681,7 +686,7 @@ testMultithreadedPostCancelPart (int flags)
   {
     const union MHD_DaemonInfo *dinfo;
     dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-    if ((NULL == dinfo) ||(0 == dinfo->port) )
+    if ((NULL == dinfo) || (0 == dinfo->port) )
     {
       MHD_stop_daemon (d); return 32;
     }
@@ -728,8 +733,8 @@ testMultithreadedPostCancelPart (int flags)
   {
 #ifdef _WIN32
     curl_version_info_data *curlverd = curl_version_info (CURLVERSION_NOW);
-    if ((0 != (flags & FLAG_SLOW_READ)) &&(CURLE_RECV_ERROR == errornum) &&
-        ((curlverd == NULL) ||(curlverd->ares_num < 0x073100) ) )
+    if ((0 != (flags & FLAG_SLOW_READ)) && (CURLE_RECV_ERROR == errornum) &&
+        ((curlverd == NULL) || (curlverd->ares_num < 0x073100) ) )
     {     /* libcurl up to version 7.49.0 didn't have workaround for WinSock bug */
       fprintf (stderr,
                "Ignored curl_easy_perform expected failure on W32 with \"slow read\".\n");
@@ -792,7 +797,7 @@ main (int argc, char *const *argv)
   unsigned int errorCount = 0;
   (void) argc;   /* Unused. Silent compiler warning. */
 
-  if ((NULL == argv)||(0 == argv[0]))
+  if ((NULL == argv) || (0 == argv[0]))
     return 99;
   oneone = has_in_name (argv[0], "11");
   if (0 != curl_global_init (CURL_GLOBAL_WIN32))
